      FUNCTION beard_droplet_fall_speed(diameter,T,rho_a)

* R J Hogan
* January 1996 (modified July, August 1996, October 2010, May 2012)
* The terminal fall velocity of a droplet with a given diameter at a specified
* temperature and density is calculated.
* All quantities are in SI units, except pressure in mb
* The equations are from Pruppacher and Klett "Microphysics of clouds and 
* precipitation" (or originally Beard, J. Atmos. Sci. 1976 p851-).
      IMPLICIT NONE

      REAL diameter           ! (metres)
      REAL p,T,mfp            ! pressure(mb), temperature(K), mean free path(m)
      REAL p0,T0,mfp0         ! standard values of p, T, mfp
      REAL rho_a,rho_w,rho_d  ! densities: air, water, water-air (kgm-3)
      REAL visc,st,radius     ! viscosity, surface tension, droplet radius(m)
      REAL R,g                ! gas constant, gravitational acceleration 
      REAL C1,C2,X,Y,number
      REAL beard_droplet_fall_speed
      REAL Tc, TTT

      PARAMETER(p0=1013.25,T0=293.13,mfp0=6.6e-8)
      PARAMETER(g=9.80665,R=287.05,rho_w=1000.)
      PARAMETER(Tc=647.15)
 
* Calculate parameters (the viscosity formula is from US Standard 
* Atmospheres 1976):
      p = rho_a * R * T / 1.e2                    ! ideal gas law
      rho_d = rho_w - rho_a
      mfp = mfp0 * p0 * T / (p * T0)
      visc = 1.458e-6 * T**(3./2.) / (T + 110.4)

! This is wrong 
!      st = 0.184 - 0.155e-3 * T                   ! page 104, but in SI units
! This shold be right (according to Chris Westbrook 30 May 2012)
      TTT = (Tc-T)/Tc
      st = 235.8e-3 * (TTT**1.256) * (1.0 - 0.625*TTT)

      radius = diameter / 2.

      IF (radius .lt. 10.e-6) THEN
* This formula (Stokes) is valid for radii: a < 10um.
         C1 = 1.26 * mfp
         C2 = 2. * g * rho_d / (9. * visc)
         beard_droplet_fall_speed
     &    = (1. + C1 / radius) * C2 * radius*radius

      ELSE IF (radius .lt. 535.e-6) THEN
* This formula is valid for radii: 10 < a < 535um.
         C1 = 32. * g * rho_d * rho_a / (3. * visc*visc)
         C2 = visc / (2 * rho_a)
         X = log( C1 * radius**3 )
         Y = -3.18657 + X*(0.992696 + X*(-0.153193e-2 + X*(-0.987059e-3 
     &     + X*(-0.578878e-3 + X*(0.855176e-4 - X*0.327815e-5)))))
         beard_droplet_fall_speed = C2 * exp(Y) / radius
      
      ELSE
* This formula is valid for radii: 535um < a < 3.5mm.
         number = ( st**3 * rho_a*rho_a
     &        / (visc**4 * g * rho_d) )**(1./6.)
         C1 = number * g * rho_d * 16. / (3. * st)
         C2 = number * visc / (2 * rho_a)
         X = log( C1 * radius*radius )
         Y = -5.00015 + X*(5.23778 + X*(-2.04914 + X*(0.475294
     &     + X*(-5.42819e-2 + X*0.238449e-2))))
         beard_droplet_fall_speed = C2 * exp(Y) / radius

      END IF 

      END





